==> contentstack-1.0.0.tgz: package/lib/request.js <==
'use strict';
/**
 * Module dependencies.
 */
var HTTPRequest;
var Utils = require('./utils');

// if script is running under node.js then use node-XMLHttpRequest node modules for the built-in http client to emulate the browser XMLHttpRequest object.
// else assign XMLHttpRequest object
if (Utils.isBrowser() && XMLHttpRequest) {
    HTTPRequest = XMLHttpRequest;
} else {
    HTTPRequest = require('xmlhttprequest').XMLHttpRequest;
}

function Request(options, callback) {
    var xhr = new HTTPRequest(),
        method = options.method || "GET",
        url = options.url,
        headers = options.headers;

    // make a request
    xhr.open(method, url, true);

    // set headers
    xhr.setRequestHeader('Content-Type', 'application/json; charset=UTF-8');
    for (var header in headers) {
        xhr.setRequestHeader(header, headers[header]);
    }

    // send stringify data
    if (options.body && method == "POST" || method == "PUT") {
        if (typeof options.body === 'object') {
            xhr.send(JSON.stringify(options.body));
        } else {
            xhr.send(options.body);
        }
    } else {
        xhr.send();
    }

    // collect response
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4) {
            var data = xhr.responseText;
            try {
                data = JSON.parse(data);
            } catch (e) {
                console.error('Could not parse the response received from the server.');
            }
            if (xhr.status >= 200 && xhr.status < 300) {
                callback(null, data);
            } else {
                callback(data, null);
            }
        }
    };
}

/**
 * Expose `Request`.
 */
module.exports = Request;

==> contentstack-1.0.2.tgz: package/lib/request.js <==
'use strict';
/**
 * Module dependencies.
 */
var HTTPRequest;
var Utils = require('./utils');

// if script is running under node.js then use node-XMLHttpRequest node modules for the built-in http client to emulate the browser XMLHttpRequest object.
// else assign XMLHttpRequest object
if (Utils.isBrowser() && XMLHttpRequest) {
    HTTPRequest = XMLHttpRequest;
} else {
    HTTPRequest = require('xmlhttprequest').XMLHttpRequest;
}

function Request(options, callback) {
    var xhr = new HTTPRequest(),
        method = options.method || "GET",
        url = options.url,
        headers = options.headers;

    // make a request
    xhr.open(method, url, true);

    // set headers
    xhr.setRequestHeader('Content-Type', 'application/json; charset=UTF-8');
    for (var header in headers) {
        xhr.setRequestHeader(header, headers[header]);
    }

    // send stringify data
    if (options.body && method == "POST" || method == "PUT") {
        if (typeof options.body === 'object') {
            xhr.send(JSON.stringify(options.body));
        } else {
            xhr.send(options.body);
        }
    } else {
        xhr.send();
    }

    // collect response
    xhr.onreadystatechange = function() {
        if (xhr.readyState === 4) {
            var data = xhr.responseText,
                error;
            try {
                data = JSON.parse(data);
            } catch (e) {
                error = {error_code: 141, message: 'Could not parse the response received from the server.'};
            }
            if (xhr.status >= 200 && xhr.status < 300) {
                callback(null, data);
            } else {
                callback(data || error, null);
            }
        }
    };
}

/**
 * Expose `Request`.
 */
module.exports = Request;
